@@ -13,7 +13,6 @@ from . import timeseries_data_states
 from . import timeseries
 from . import timeseries_property_data
 from . import timeseries_data
-from . import event_levels
 from . import event_categories
 from . import events
 from . import timeseries_by_events
@@ -68,7 +67,6 @@ MODULES = (
     timeseries,
     timeseries_property_data,
     timeseries_data,
-    event_levels,
     event_categories,
     events,
     timeseries_by_events,
